#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mmap
version:              0.5.9
visibility:           public
id:                   mmap-0.5.9-AiaaDT3AznV3aaEfoYTVVt
key:                  mmap-0.5.9-AiaaDT3AznV3aaEfoYTVVt
license:              BSD-3-Clause
copyright:            2008-2012, Gracjan Polak
maintainer:           Gracjan Polak <gracjanpolak@gmail.com>
author:               Gracjan Polak <gracjanpolak@gmail.com>
stability:            stable
synopsis:             Memory mapped files for POSIX and Windows
description:
    This library provides a wrapper to mmap(2) or MapViewOfFile,
    allowing files or devices to be lazily loaded into memory as
    strict or lazy ByteStrings, ForeignPtrs or plain Ptrs, using
    the virtual memory subsystem to do on-demand loading.
    Modifications are also supported.

category:             System
abi:                  103559a9aede7085bc104507a092261c
exposed:              True
exposed-modules:      System.IO.MMap
import-dirs:          /usr/lib/ghc-9.6.6/site-local/mmap-0.5.9
library-dirs:         /usr/lib/ghc-9.6.6/site-local/mmap-0.5.9
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/mmap-0.5.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mmap
hs-libraries:         HSmmap-0.5.9-AiaaDT3AznV3aaEfoYTVVt
depends:              base-4.18.2.1 bytestring-0.11.5.3
haddock-interfaces:   /usr/share/doc/haskell-mmap/html/mmap.haddock
haddock-html:         /usr/share/doc/haskell-mmap/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

